@@ -311,19 +311,17 @@ module Puppet::Network::HTTP
     rescue => exception
       elapsed = (Time.now - start).to_f.round(3)
       uri = [@site.addr, request.path.split('?')[0]].join('/')
-      eclass = exception.class
 
-      err = case exception
-            when EOFError
-              eclass.new(_('request %{uri} interrupted after %{elapsed} seconds') % {uri: uri, elapsed: elapsed})
-            when Timeout::Error
-              eclass.new(_('request %{uri} timed out after %{elapsed} seconds') % {uri: uri, elapsed: elapsed})
-            else
-              eclass.new(_('request %{uri} failed: %{msg}') % {uri: uri, msg: exception.message})
-            end
+      case exception
+      when EOFError
+        Puppet.log_exception(exception, _('request %{uri} interrupted after %{elapsed} seconds') % {uri: uri, elapsed: elapsed})
+      when Timeout::Error
+        Puppet.log_exception(exception, _('request %{uri} timed out after %{elapsed} seconds') % {uri: uri, elapsed: elapsed})
+      else
+        Puppet.log_exception(exception, _('request %{uri} failed: %{msg}') % {uri: uri, msg: exception.message})
+      end
 
-      err.set_backtrace(exception.backtrace) unless exception.backtrace.empty?
-      raise err
+      raise exception
     end
 
     def with_connection(site, &block)
