@@ -145,7 +145,7 @@ Puppet::Type.type(:package).provide :dpkg, :parent => Puppet::Provider::Package
   end
 
   def hold
-    if package_not_installed?(@resource[:name])
+    if package_not_installed?
       self.install
     end
     Tempfile.open('puppet_dpkg_set_selection') do |tmpfile|
@@ -163,16 +163,7 @@ Puppet::Type.type(:package).provide :dpkg, :parent => Puppet::Provider::Package
     end
   end
 
-  def package_not_installed?(name)
-    if !name.nil? && !name.empty?
-      begin
-       dpkgquery("-W", "--showformat", self.class::DPKG_QUERY_FORMAT_STRING, name)
-      rescue Puppet::ExecutionFailure
-        # return true if exception is generated because package is not found
-        return true
-      end
-      return false
-    end
-    raise ArgumentError.new("Package name is nil or empty")
+  def package_not_installed?
+    query[:status] != "installed"
   end
 end
